@@ -1,6 +1,6 @@
 use std::cell::UnsafeCell;
 use std::ptr;
-use std::sync::atomic::{spin_loop_hint, AtomicPtr, Ordering};
+use std::sync::atomic::{AtomicPtr, Ordering};
 use std::thread;
 
 use crossbeam::utils::CachePadded;
@@ -27,8 +27,8 @@ pub struct Queue<T> {
     tail: UnsafeCell<*mut Node<T>>,
 }
 
-unsafe impl<T> Send for Queue<T> {}
-unsafe impl<T> Sync for Queue<T> {}
+unsafe impl<T: Send> Send for Queue<T> {}
+unsafe impl<T: Send> Sync for Queue<T> {}
 
 impl<T> Queue<T> {
     /// Creates a new queue that is safe to share among multiple producers and
@@ -77,13 +77,12 @@ impl<T> Queue<T> {
                 }
                 i += 1;
                 if i > 100 {
-                    #[cold]
                     {
                         thread::yield_now();
                         i = 0;
                     }
                 } else {
-                    spin_loop_hint()
+                    std::hint::spin_loop()
                 }
             }
             // value is not an atomic operation it may read out old shadow value
@@ -109,7 +108,7 @@ impl<T> Default for Queue<T> {
 
 impl<T> Drop for Queue<T> {
     fn drop(&mut self) {
-        while let Some(_) = self.pop() {}
+        while self.pop().is_some() {}
         // release the stub
         let _: Box<Node<T>> = unsafe { Box::from_raw(*self.tail.get()) };
     }
