@@ -1,6 +1,6 @@
 use std::cell::UnsafeCell;
 use std::ptr;
-use std::sync::atomic::{spin_loop_hint, AtomicPtr, Ordering};
+use std::sync::atomic::{AtomicPtr, Ordering};
 use std::thread;
 
 use crossbeam::utils::CachePadded;
@@ -31,8 +31,10 @@ pub struct Entry<T>(ptr::NonNull<Node<T>>);
 unsafe impl<T: Sync> Sync for Entry<T> {}
 
 impl<T> Entry<T> {
-    // get the internal data mut ref
-    // must make sure it's not popped by the consumer
+    /// get the internal data mut ref
+    /// # Safety
+    ///
+    /// must make sure it's not popped by the consumer
     #[inline]
     pub unsafe fn with_mut_data<F>(&self, f: F)
     where
@@ -58,6 +60,9 @@ impl<T> Entry<T> {
     }
 
     #[inline]
+    /// # Safety
+    ///
+    /// Must use the ptr that from `Entry::into_ptr`
     pub unsafe fn from_ptr(ptr: *mut Self) -> Self {
         Entry(ptr::NonNull::new_unchecked(ptr as *mut Node<T>))
     }
@@ -71,7 +76,6 @@ impl<T> Entry<T> {
             // when the link bit is cleared, next and prev is no longer valid
             if node.refs & !REF_COUNT_MASK == 0 {
                 // already removed
-                #[cold]
                 return None;
             }
 
@@ -107,7 +111,6 @@ impl<T> Entry<T> {
                 node.refs -= 1;
                 if node.refs == 0 {
                     // release the node only when the ref count becomes 0
-                    #[cold]
                     let _: Box<Node<T>> = Box::from_raw(node);
                 }
 
@@ -144,8 +147,8 @@ pub struct Queue<T> {
     tail: UnsafeCell<*mut Node<T>>,
 }
 
-unsafe impl<T> Send for Queue<T> {}
-unsafe impl<T> Sync for Queue<T> {}
+unsafe impl<T: Send> Send for Queue<T> {}
+unsafe impl<T: Send> Sync for Queue<T> {}
 
 impl<T> Queue<T> {
     /// Creates a new queue that is safe to share among multiple producers and
@@ -202,13 +205,12 @@ impl<T> Queue<T> {
                 }
                 i += 1;
                 if i > 500 {
-                    #[cold]
                     {
                         thread::yield_now();
                         i = 0;
                     }
                 } else {
-                    spin_loop_hint()
+                    std::hint::spin_loop()
                 }
             }
 
@@ -299,13 +301,12 @@ impl<T> Queue<T> {
                 }
                 i += 1;
                 if i > 100 {
-                    #[cold]
                     {
                         thread::yield_now();
                         i = 0;
                     }
                 } else {
-                    spin_loop_hint()
+                    std::hint::spin_loop()
                 }
             }
             (*next).prev = ptr::null_mut();
@@ -335,7 +336,7 @@ impl<T> Default for Queue<T> {
 
 impl<T> Drop for Queue<T> {
     fn drop(&mut self) {
-        while let Some(_) = self.pop() {}
+        while self.pop().is_some() {}
         // release the stub
         let _: Box<Node<T>> = unsafe { Box::from_raw(*self.tail.get()) };
     }
